@@ -2,12 +2,10 @@
 # from tf_transformers.layers.bert_transformer import TransformerBERT
 # from tf_transformers.layers.attention import GPT2Attention
 # from tf_transformers.layers.multihead_attention  import MultiHeadAttention
-from tf_transformers.layers.layer_normalization import (GPT2LayerNormalization,
-                                                        T5LayerNormalization)
+from tf_transformers.layers.layer_normalization import GPT2LayerNormalization, T5LayerNormalization
 from tf_transformers.layers.mlm_layer import MLMLayer
 from tf_transformers.layers.on_device_embedding import OnDeviceEmbedding
-from tf_transformers.layers.position_embedding import (PositionEmbedding,
-                                                       SimplePositionEmbedding)
+from tf_transformers.layers.position_embedding import PositionEmbedding, SimplePositionEmbedding
 
 # from tf_transformers.layers.self_attention_mask  import SelfAttentionMask
 # from tf_transformers.layers.cross_attention_mask import CrossAttentionMask
