@@ -292,8 +292,6 @@ class T5Attention(LegacyLayer):
             key_tensor = tf.transpose(key_tensor, [0, 2, 1, 3])
             value_tensor = tf.transpose(value_tensor, [0, 2, 1, 3])
 
-
-
             if cross_decoder_mode:
                 attention_scores = tf.einsum("BNFH,BNTH->BNFT", query_tensor, key_tensor)
                 if position_bias is None:
@@ -338,7 +336,6 @@ class T5Attention(LegacyLayer):
                     #                                   position_bias.dtype) * -1e+09, 1)
                     # position_bias += positon_mask
 
-
                 attention_scores = tf.einsum("BNFH,BNTH->BNFT", query_tensor, key_tensor)
                 # T5 don't have this
                 # attention_scores = tf.multiply(attention_scores,
@@ -440,7 +437,9 @@ class T5Attention(LegacyLayer):
                     num_buckets=self._positional_buckets,
                 )
                 values = self._relative_embedding(rp_bucket)  # shape (qlen, klen, num_heads)
-                position_bias = tf.expand_dims(tf.transpose(values, [2, 0, 1]), axis=0)  # shape (1, num_heads, qlen, klen)
+                position_bias = tf.expand_dims(
+                    tf.transpose(values, [2, 0, 1]), axis=0
+                )  # shape (1, num_heads, qlen, klen)
                 # To account for masking in postional buckets
                 positon_mask = tf.expand_dims(
                     tf.cast(tf.not_equal(attention_mask, 1.0), position_bias.dtype) * -1e09,
@@ -455,8 +454,6 @@ class T5Attention(LegacyLayer):
             position_bias = tf.zeros_like(attention_scores)
             attention_scores += position_bias
 
-
-
         attention_probs = self._masked_softmax([attention_scores, attention_mask])
         # This is actually dropping out entire tokens to attend to, which might
         # seem a bit unusual, but is taken from the original Transformer paper.
