@@ -5,9 +5,8 @@ from absl import logging
 
 from tf_transformers.activations import get_activation
 from tf_transformers.core import LegacyLayer
-from tf_transformers.layers import (MLMLayer, OnDeviceEmbedding,
-                             SimplePositionEmbedding, dense_einsum)
-from tf_transformers.layers.mask import CausalMask, SelfAttentionMask, prefix_mask, CrossAttentionMask
+from tf_transformers.layers import MLMLayer, OnDeviceEmbedding, SimplePositionEmbedding, dense_einsum
+from tf_transformers.layers.mask import CausalMask, CrossAttentionMask, SelfAttentionMask, prefix_mask
 from tf_transformers.layers.transformer import TransformerBERT
 
 logging.set_verbosity("INFO")
@@ -48,6 +47,7 @@ class AlbertEncoder(LegacyLayer):
         encoder_positional_embedding_layer=None,
         use_mlm_layer=False,
         return_all_layer_token_embeddings=True,
+        attention_type="full_attention",
         **kwargs,
     ):
         """
@@ -81,7 +81,7 @@ class AlbertEncoder(LegacyLayer):
         self.type_vocab_size = config["type_vocab_size"]
         self.num_hidden_layers = config["num_hidden_layers"]
         self.num_attention_heads = config["num_attention_heads"]
-        self.attention_head_size = config['attention_head_size']
+        self.attention_head_size = config["attention_head_size"]
         self.max_position_embeddings = config["max_position_embeddings"]
         self.intermediate_size = config["intermediate_size"]
         self.embedding_size = config["embedding_size"]
@@ -117,6 +117,7 @@ class AlbertEncoder(LegacyLayer):
         self.use_mlm_layer = use_mlm_layer
         self.cross_attention_inside_encoder = cross_attention_inside_encoder
         self.return_all_layer_token_embeddings = return_all_layer_token_embeddings
+        self.attention_type = attention_type
 
         if not name.startswith("tf_transformers"):
             kwargs["name"] = "tf_transformers/" + self.model_name
@@ -138,14 +139,16 @@ class AlbertEncoder(LegacyLayer):
             "share_encoder_embeddings": self.share_encoder_embeddings,
             "share_attention_layers": self.share_attention_layers,
             "cross_attention_inside_encoder": self.cross_attention_inside_encoder,
-            "return_all_layer_token_embeddings": return_all_layer_token_embeddings
+            "return_all_layer_token_embeddings": return_all_layer_token_embeddings,
         }
 
         # Update config dict with passed config
         self._config_dict.update(config)
 
         # Call embedding layers
-        self._embedding_layer, self._type_embeddings, self._position_embedding_layer = self.get_embedding_layers(self.embedding_projection_size)
+        self._embedding_layer, self._type_embeddings, self._position_embedding_layer = self.get_embedding_layers(
+            self.embedding_projection_size
+        )
         if self.is_decoder:
             # If embedding has to shared from the encoder
             if self.share_encoder_embeddings:
@@ -188,6 +191,7 @@ class AlbertEncoder(LegacyLayer):
             share_attention_layers=share_attention_layers,
             layer_norm_epsilon=self.layer_norm_epsilon,
             cross_attention_inside_encoder=self.cross_attention_inside_encoder,
+            attention_type=self.attention_type,
             name="transformer/layer",
         )
 
@@ -218,12 +222,20 @@ class AlbertEncoder(LegacyLayer):
                 name="mlm_layer",
             )
 
-            self._last_logits_bias = self.add_weight(
-                "tf_transformers/last_logits_bias",
-                shape=(self.vocab_size,),
-                dtype=tf.float32,
-                trainable=True,
-            )
+        self._last_logits_bias = self.add_weight(
+            "tf_transformers/last_logits_bias",
+            shape=(self.vocab_size,),
+            dtype=tf.float32,
+            trainable=True,
+        )
+
+        # Embedding Norm
+        self._last_layer_norm = tf.keras.layers.LayerNormalization(
+            name="last/layer_norm",
+            axis=-1,
+            epsilon=self.layer_norm_epsilon,
+            dtype=tf.float32,
+        )
         self.call_fn = self.get_call_method()
         # Initialize model
         self.model_inputs, self.model_outputs = self.get_model(initialize_only=True)
@@ -350,18 +362,6 @@ class AlbertEncoder(LegacyLayer):
             )
             encoder_outputs.append(embeddings)
 
-        def step_0_gather(past_length):
-            cache_length = tf.reduce_sum(tf.cast(tf.not_equal(input_ids_mod, -1), tf.int32), axis=1) - 1
-            # Getting corresponding last token tensor and last token logits
-            last_token_tensor = tf.gather_nd(embeddings, tf.expand_dims(cache_length, axis=1), batch_dims=1)
-            past_length = past_length + cache_length
-            return past_length, last_token_tensor
-
-        def step_other_gather(past_length):
-            past_length = past_length + sequence_length
-            last_token_tensor = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(encoder_outputs[-1])
-            return past_length, last_token_tensor
-
         # First word of last layer outputs [CLS]
         cls_token_tensor = tf.keras.layers.Lambda(lambda x: tf.squeeze(x[:, 0:1, :], axis=1))(encoder_outputs[-1])
         # batch_size x embedding_size
@@ -370,16 +370,6 @@ class AlbertEncoder(LegacyLayer):
         # batch_size x sequence_length x embedding_size
         token_embeddings = encoder_outputs[-1]
 
-        # Condition to switch functionsn (When batch_size > 1,\
-        #  past_length will be different for each entry) # noqa
-        # if `sum(past_length) = 0` , means no outputs has been\
-        #  generated. the given inputs is the first input # noqa
-        past_length, last_token_tensor = tf.cond(
-            tf.equal(tf.reduce_sum(past_length), 0),
-            lambda: step_0_gather(past_length),
-            lambda: step_other_gather(past_length),
-        )
-
         # MLM Projection
         if self.use_mlm_layer:
             # This matrix won't be used after pretraining
@@ -405,7 +395,51 @@ class AlbertEncoder(LegacyLayer):
                 name="token_logits",
             )
 
-        last_token_logits = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(token_logits)
+        def step_0_gather(past_length, token_embeddings):
+            cache_length = tf.reduce_sum(tf.cast(tf.not_equal(input_ids_mod, -1), tf.int32), axis=1) - 1
+            # Getting corresponding last token tensor and last token logits
+            last_token_tensor = tf.gather_nd(token_embeddings, tf.expand_dims(cache_length, axis=1), batch_dims=1)
+            past_length = past_length + cache_length
+            return past_length, last_token_tensor
+
+        def step_other_gather(past_length, token_embeddings):
+            past_length = past_length + sequence_length
+            last_token_tensor = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(token_embeddings)
+            return past_length, last_token_tensor
+
+        # Condition to switch functionsn (When batch_size > 1,
+        # past_length will be different for each entry)
+        # if `sum(past_length) = 0` , means no outputs has been generated.
+        # the given inputs is the first input
+        past_length, last_token_tensor = tf.cond(
+            tf.equal(tf.reduce_sum(past_length), 0),
+            lambda: step_0_gather(past_length, token_embeddings_projected),
+            lambda: step_other_gather(past_length, token_embeddings_projected),
+        )
+
+        # token --> vocab ( batch_size x sequence_length x vocab_size)
+        last_token_logits = tf.matmul(
+            last_token_tensor,
+            self.get_embedding_table(),
+            transpose_b=True,
+            name="token_logits",
+        )
+        # last_token_logits = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(token_logits)
+
+        # Expand dims of past_length back to 2D
+        past_length = tf.expand_dims(past_length, 0, name="past_length")
+        # Stack all layers key and value together
+        # num_layers x batch_size x num_heads x sequence_length x (hidden_dimension/num_heads)
+        all_cache_key = tf.stack(all_cache_key, axis=0, name="all_cache_key")
+        all_cache_value = tf.stack(all_cache_value, axis=0, name="all_cache_value")
+
+        return {
+            "token_embeddings": token_embeddings_projected,
+            "last_token_logits": last_token_logits,
+            "past_length": past_length,
+            "all_cache_key": all_cache_key,
+            "all_cache_value": all_cache_value,
+        }
 
         # Expand dims of past_length back to 2D
         past_length = tf.expand_dims(past_length, 0, name="past_length")
@@ -481,6 +515,13 @@ class AlbertEncoder(LegacyLayer):
         # batch_size x embedding_size
         cls_output = self._pooler_layer(cls_token_tensor)
 
+        all_cls_output = []
+        for per_layer_token_embeddings in encoder_outputs:
+            per_cls_token_tensor = tf.keras.layers.Lambda(lambda x: tf.squeeze(x[:, 0:1, :], axis=1))(
+                per_layer_token_embeddings
+            )
+            all_cls_output.append(self._pooler_layer(per_cls_token_tensor))
+
         # MLM Projection
         if self.use_mlm_layer:
             # This matrix won't be used after pretraining
@@ -489,7 +530,7 @@ class AlbertEncoder(LegacyLayer):
             # token --> vocab ( batch_size x sequence_length x vocab_size)
             token_logits = (
                 tf.matmul(
-                    token_embeddings,
+                    tf.cast(token_embeddings, tf.float32),
                     self.get_embedding_table(),
                     transpose_b=True,
                     name="token_logits",
@@ -497,13 +538,21 @@ class AlbertEncoder(LegacyLayer):
                 + self._last_logits_bias
             )
         else:
+            policy = tf.keras.mixed_precision.experimental.global_policy()
+            if policy.name == "mixed_float16":
+                policy = tf.float16
+                # token_embeddings = tf.cast(token_embeddings, policy)
             token_embeddings_projected = self._lower_embedding_projection(token_embeddings)
+            token_embeddings_projected = self._last_layer_norm(token_embeddings_projected)
             # # token --> vocab ( batch_size x sequence_length x vocab_size)
-            token_logits = tf.matmul(
-                token_embeddings_projected,
-                self.get_embedding_table(),
-                transpose_b=True,
-                name="token_logits",
+            token_logits = (
+                tf.matmul(
+                    tf.cast(token_embeddings_projected, tf.float32),
+                    self.get_embedding_table(),
+                    transpose_b=True,
+                    name="token_logits",
+                )
+                + self._last_logits_bias
             )
 
         last_token_logits = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(token_logits)
@@ -516,7 +565,8 @@ class AlbertEncoder(LegacyLayer):
         }
 
         if self.return_all_layer_token_embeddings:
-            result['all_layer_token_embeddings'] = encoder_outputs
+            result["all_layer_token_embeddings"] = encoder_outputs
+            result["all_layer_cls_output"] = all_cls_output
         return result
 
     def call_cross_attention_encoder(self, inputs):
@@ -585,10 +635,10 @@ class AlbertEncoder(LegacyLayer):
                 [
                     encoder_embeddings,
                     encoder_attention_mask,
-                    decoder_encoder_mask, # dummy decoder_encoder_mask
-                    encoder_embeddings, # dummy encoder_hidden_states
+                    decoder_encoder_mask,  # dummy decoder_encoder_mask
+                    encoder_embeddings,  # dummy encoder_hidden_states
                 ],
-                mode = 'encoder'
+                mode="encoder",
             )
             encoder_outputs.append(encoder_embeddings)
 
@@ -597,13 +647,8 @@ class AlbertEncoder(LegacyLayer):
         for i in range(self.num_hidden_layers):
             layer = self._transformer_layers[i]
             decoder_embeddings, _, _ = layer(
-                [
-                    decoder_embeddings,
-                    decoder_attention_mask,
-                    decoder_encoder_mask,
-                    encoder_hidden_states
-                ],
-                mode = 'decoder'
+                [decoder_embeddings, decoder_attention_mask, decoder_encoder_mask, encoder_hidden_states],
+                mode="decoder",
             )
             decoder_outputs.append(decoder_embeddings)
         # First word of last layer outputs [CLS]
@@ -630,7 +675,6 @@ class AlbertEncoder(LegacyLayer):
             )
         else:
             token_embeddings_projected = self._lower_embedding_projection(token_embeddings)
-            print("Token embeddings projected", token_embeddings_projected)
             # # token --> vocab ( batch_size x sequence_length x vocab_size)
             token_logits = tf.matmul(
                 token_embeddings_projected,
@@ -648,7 +692,7 @@ class AlbertEncoder(LegacyLayer):
             "last_token_logits": last_token_logits,
         }
         if self.return_all_layer_token_embeddings:
-            result['all_layer_token_embeddings'] = decoder_outputs
+            result["all_layer_token_embeddings"] = decoder_outputs
         return result
 
     def call_cross_attention_encoder_predict(self, inputs):
@@ -709,6 +753,7 @@ class AlbertEncoder(LegacyLayer):
                 input_ids ([type]): [description]
                 input_type_ids ([type]): [description]
             """
+
             def step_0_cache_length(_):
                 return tf.constant(0, dtype=tf.int32)
 
@@ -770,7 +815,7 @@ class AlbertEncoder(LegacyLayer):
 
         # Decoder mask is always None
         decoder_attention_mask = CausalMask()(decoder_embeddings)
-        decoder_encoder_mask   = CrossAttentionMask()([decoder_input_ids, encoder_input_mask])
+        decoder_encoder_mask = CrossAttentionMask()([decoder_input_ids, encoder_input_mask])
 
         all_cache_key = [
             tf.squeeze(item, axis=0)
@@ -792,12 +837,12 @@ class AlbertEncoder(LegacyLayer):
                     [
                         encoder_embeddings,
                         encoder_attention_mask,
-                        decoder_encoder_mask, # decoder_encoder_mask
+                        decoder_encoder_mask,  # decoder_encoder_mask
                         encoder_embeddings,
                     ],
-                    mode = 'encoder',
-                cache_key=cache_key,
-                cache_value=cache_value,
+                    mode="encoder",
+                    cache_key=cache_key,
+                    cache_value=cache_value,
                 )
                 encoder_outputs.append(encoder_embeddings)
             encoder_hidden_states = encoder_outputs[-1]
@@ -826,7 +871,7 @@ class AlbertEncoder(LegacyLayer):
                     decoder_encoder_mask,
                     encoder_hidden_states,
                 ],
-                mode = 'decoder',
+                mode="decoder",
                 cache_key=cache_key,
                 cache_value=cache_value,
             )
@@ -883,7 +928,6 @@ class AlbertEncoder(LegacyLayer):
             "last_token_logits": last_token_logits,
         }
 
-
     def call_decoder_predict(self, inputs):
         """Inputs will be pass to this method, when \
             is_training = False and is_decoder = True.
@@ -1110,14 +1154,14 @@ class AlbertEncoder(LegacyLayer):
 
         last_token_logits = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(token_logits)
 
-        return {
+        result = {
             "cls_output": cls_output,
             "token_embeddings": token_embeddings,
             "token_logits": token_logits,
             "last_token_logits": last_token_logits,
         }
         if self.return_all_layer_token_embeddings:
-            result['all_layer_token_embeddings'] = decoder_outputs
+            result["all_layer_token_embeddings"] = decoder_outputs
         return result
 
     def call(self, inputs):
