@@ -1,3 +1,3 @@
 from tf_transformers.pipeline.span_extraction_pipeline import Span_Extraction_Pipeline
 from tf_transformers.pipeline.token_classification_pipeline import Token_Classification_Pipeline
-from tf_transformers.pipeline.classification_ipeline import Classification_Pipeline
+from tf_transformers.pipeline.classification_pipeline import Classification_Pipeline
