@@ -1,9 +1,7 @@
 import numpy as np
 import tensorflow as tf
 
-from tf_transformers.text import (_gather_beams, _log_prob_from_logits,
-                                  assign_zeros_to_K_V, top_k_logits,
-                                  top_p_logits)
+from tf_transformers.text import _gather_beams, _log_prob_from_logits, assign_zeros_to_K_V, top_k_logits, top_p_logits
 
 tf.keras.backend.clear_session()
 
